@@ -1,18 +1,17 @@
-import os
 import itertools
+import pytest
 
 import numpy as np
-from skimage import data_dir
-from skimage.io import imread
+from skimage.data import shepp_logan_phantom
 from skimage.transform import radon, iradon, iradon_sart, rescale
 
+from skimage._shared.utils import convert_to_float
 from skimage._shared import testing
 from skimage._shared.testing import test_parallel
 from skimage._shared._warnings import expected_warnings
 
 
-PHANTOM = imread(os.path.join(data_dir, "phantom.png"),
-                 as_gray=True)[::2, ::2]
+PHANTOM = shepp_logan_phantom()[::2, ::2]
 PHANTOM = rescale(PHANTOM, 0.5, order=1,
                   mode='constant', anti_aliasing=False, multichannel=False)
 
@@ -62,7 +61,7 @@ def test_iradon_bias_circular_phantom():
 
     tol = 5e-5
     roi_err = np.abs(np.mean(error))
-    assert( roi_err < tol )
+    assert roi_err < tol
 
 
 def check_radon_center(shape, circle, dtype, preserve_range):
@@ -149,7 +148,7 @@ def test_iradon_center(size, theta, circle):
 def check_radon_iradon(interpolation_type, filter_type):
     debug = False
     image = PHANTOM
-    reconstructed = iradon(radon(image, circle=False), filter=filter_type,
+    reconstructed = iradon(radon(image, circle=False), filter_name=filter_type,
                            interpolation=interpolation_type, circle=False)
     delta = np.mean(np.abs(image - reconstructed))
     print('\n\tmean error:', delta)
@@ -179,6 +178,15 @@ def test_radon_iradon(interpolation_type, filter_type):
     check_radon_iradon(interpolation_type, filter_type)
 
 
+@pytest.mark.parametrize("filter_type", filter_types)
+def test_iradon_new_signature(filter_type):
+    image = PHANTOM
+    sinogram = radon(image, circle=False)
+    with pytest.warns(FutureWarning):
+        assert np.array_equal(iradon(sinogram, filter=filter_type),
+                              iradon(sinogram, filter_name=filter_type))
+
+
 def test_iradon_angles():
     """
     Test with different number of projections
@@ -435,3 +443,31 @@ def test_iradon_sart():
         delta = np.mean(np.abs(reconstructed - image))
         print('delta (1 iteration, shifted sinogram) =', delta)
         assert delta < 0.022 * error_factor
+
+
+def test_radon_dtype():
+    img = convert_to_float(PHANTOM, False)
+    img32 = img.astype(np.float32)
+
+    assert radon(img).dtype == img.dtype
+    assert radon(img32).dtype == img32.dtype
+
+
+def test_iradon_sart_dtype():
+    sinogram = np.zeros((16, 1), dtype=int)
+    sinogram[8, 0] = 1.
+    sinogram64 = sinogram.astype('float64')
+    sinogram32 = sinogram.astype('float32')
+
+    with expected_warnings(['Input data is cast to float']):
+        assert iradon_sart(sinogram, theta=[0]).dtype == 'float64'
+
+    assert iradon_sart(sinogram64, theta=[0]).dtype == sinogram64.dtype
+    assert iradon_sart(sinogram32, theta=[0]).dtype == sinogram32.dtype
+
+
+def test_iradon_wrong_dtype():
+    sinogram = np.zeros((16, 1))
+
+    with testing.raises(ValueError):
+        iradon_sart(sinogram, dtype=int)
